@@ -1,3 +1,3 @@
 from microconventions.url_conventions import API_URL, FAILOVER_API_URL, api_url, failover_api_url, get_config
-from microconventions.conventions import KeyConventions, StreamConventions, ValueConventions, MicroConventions
+from microconventions.conventions import KeyConventions, StreamConventions, ValueConventions, MicroConventions, RatingVariety, LeaderboardVariety
 from microconventions.key_conventions import new_key, create_key, maybe_create_key, animal_from_key, shash, animal_from_code, key_difficulty
