@@ -1,12 +1,13 @@
 
 class SepConventions(object):
 
-    # Separators used in names
+    # Separators used in names, external and internal
 
     def __init__(self ,**kwargs):
         super().__init__(**kwargs)
         self.SEP   = SepConventions.sep()
         self.TILDE = SepConventions.tilde()
+        self.PIPE = SepConventions.pipe()
 
     @staticmethod
     def sep():
@@ -15,3 +16,8 @@ class SepConventions(object):
     @staticmethod
     def tilde():
         return '~'
+
+    @staticmethod
+    def pipe():
+        return '|'
+
